#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://gtkballs.antex.ru/
# source           : http://gtkballs.antex.ru/dist/gtkballs-3.1.5.tar.gz

# Package name
NAME="gtkballs"
# Package version
VERSION="3.1.5"
# Source code URL
SOURCE="http://gtkballs.antex.ru/dist/gtkballs-$VERSION.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="ABOUT-NLS AUTHORS COPYING ChangeLog INSTALL NEWS README README.russian TODO"
# ./configure options (localstatedir is needed only for hiscores)
CONFIGOPTIONS="--prefix=/usr --localstatedir=/usr/share/$NAME"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: GtkBalls is the clone of well-known DOS game "Lines".
$NAME:
$NAME: Your objective in this game is to make horizontal, vertical or
$NAME: diagonal lines with at least five items of the same color.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=GtkBalls
Exec=gtkballs
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=gtkballs
EOF

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if source is present. If it's not, download it and put it in the right place
if [ -f $NAME.png ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/$NAME.png
fi
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp -a $NAME.png $PKG/usr/share/icons/hicolor/48x48/apps

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# But we need the hiscores file writable by everyone
chmod a+w $PKG/usr/share/gtkballs/gtkballs-scores

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
